@@ -1304,6 +1304,12 @@ username:
 count_star:
     kind: Metric
     field: "count(*)"
+convertdate:
+    kind: Dimension
+    field: "month(test_date)"
+strings:
+    kind: Dimension
+    field: "string(test_date)+string(score)"
 total_nulls:
     kind: Metric
     field: "count_distinct(if(score IS NULL, username))"
@@ -1443,6 +1449,37 @@ FROM scores_with_nulls"""
         )
         self.assert_recipe_csv(recipe, "parentheses\n0.5\n")
 
+        recipe = (
+            Recipe(shelf=shelf, session=self.session)
+            .dimensions("convertdate")
+            .metrics("count_star")
+        )
+        assert (
+            recipe.to_sql()
+            == """SELECT date_trunc('month', scores_with_nulls.test_date) AS convertdate,
+       count(*) AS count_star
+FROM scores_with_nulls
+GROUP BY convertdate"""
+        )
+        # Can't run this against sqlite so we don't test csv
+
+        recipe = Recipe(shelf=shelf, session=self.session).dimensions("strings")
+        assert (
+            recipe.to_sql()
+            == """SELECT CAST(scores_with_nulls.test_date AS VARCHAR) || CAST(scores_with_nulls.score AS VARCHAR) AS strings
+FROM scores_with_nulls
+GROUP BY strings"""
+        )
+        self.assert_recipe_csv(
+            recipe,
+            """strings,strings_id
+,
+2005-01-0480.0,2005-01-0480.0
+2005-01-07100.0,2005-01-07100.0
+2005-02-0180.0,2005-02-0180.0
+""",
+        )
+
     def test_selectables(self):
         """Test parsed field definitions built on top of other selectables"""
         shelf = self.create_shelf(
@@ -1494,7 +1531,6 @@ max_username:
         recipe2 = Recipe(shelf=shelf2, session=self.session).metrics(
             "count_star", "max_username"
         )
-        print("two")
         assert (
             recipe2.to_sql()
             == """SELECT count(*) AS count_star,
